// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KWEATHERCORE_VERSION_H
#define KWEATHERCORE_VERSION_H

#define KWEATHERCORE_VERSION_STRING "25.04.0"
#define KWEATHERCORE_VERSION_MAJOR 25
#define KWEATHERCORE_VERSION_MINOR 4
#define KWEATHERCORE_VERSION_PATCH 0
#define KWEATHERCORE_VERSION ((25<<16)|(4<<8)|(0))

#endif
